@@ -12,15 +12,16 @@ IntAUC = function(x, y, t1, t2, Res, down="Linear")
 #  Res: result of sNCA
 #  down: "Linear" or "Log" 
 # RETURN
-  Result = NA_real_ # Interval AUC
+#  Interval AUC
 
 # Input check
-  n = length(x)
-  if (n != length(y) | !is.numeric(x) | !is.numeric(y)) return(Result)
-  if (t1 > Res["TLST"]) return(Result)
+  if (all(y == 0) & min(x, na.rm=T) <= t1 & max(x, na.rm=T) >= t2) return(0)
+  n = length(x)  
+  if (n != length(y) | !is.numeric(x) | !is.numeric(y)) return(NA_real_)
+  if (is.na(Res["TLST"]) | t1 > Res["TLST"]) return(NA_real_)
 
   tL = Res["TLST"]
-  if (t2 > tL & is.na(Res["LAMZ"])) return(Result)
+  if (t2 > max(x[!is.na(y)]) & is.na(Res["LAMZ"])) return(NA_real_)
 
   newSeries = Interpol(x, y, t1, Res["LAMZ"], Res["b0"], down=down)
   newSeries = Interpol(newSeries[[1]], newSeries[[2]], t2, Res["LAMZ"], Res["b0"], down=down)
